@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Prereqs::EnsureCoreOrPP;
 
 our $DATE = '2015-04-21'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,7 +12,7 @@ with 'Dist::Zilla::Role::InstallTool';
 
 use IPC::System::Options qw(backtick);
 use JSON;
-use Module::CoreList::More qw(is_still_core);
+use Module::CoreList::More;
 use Module::Path::More qw(module_path);
 use Module::XSOrPP qw(is_pp);
 use namespace::autoclean;
@@ -36,7 +36,7 @@ sub setup_installer {
         if (!module_path(module=>$mod)) {
             $self->log_fatal(["Prerequisite %s is not installed", $mod]);
         }
-        if (!is_pp($mod) && !is_still_core($mod)) {
+        if (!is_pp($mod) && !Module::CoreList::More->is_still_core($mod)) {
             $self->log_fatal(["Prerequisite %s is not PP nor core", $mod]);
         }
     }
@@ -58,7 +58,7 @@ Dist::Zilla::Plugin::Prereqs::EnsureCoreOrPP - Make sure that prereqs (and their
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::Prereqs::EnsureCoreOrPP (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP), released on 2015-04-21.
+This document describes version 0.03 of Dist::Zilla::Plugin::Prereqs::EnsureCoreOrPP (from Perl distribution Dist-Zilla-Plugin-Prereqs-EnsureCoreOrPP), released on 2015-04-21.
 
 =head1 SYNOPSIS
 
